import reflex as rx

class LuAccessibility(rx.Component):
    library = "react-icons/lu"
    tag = "LuAccessibility"


class LuActivity(rx.Component):
    library = "react-icons/lu"
    tag = "LuActivity"


class LuAirVent(rx.Component):
    library = "react-icons/lu"
    tag = "LuAirVent"


class LuAirplay(rx.Component):
    library = "react-icons/lu"
    tag = "LuAirplay"


class LuAlarmCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlarmCheck"


class LuAlarmClockOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlarmClockOff"


class LuAlarmClock(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlarmClock"


class LuAlarmMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlarmMinus"


class LuAlarmPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlarmPlus"


class LuAlbum(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlbum"


class LuAlertCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlertCircle"


class LuAlertOctagon(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlertOctagon"


class LuAlertTriangle(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlertTriangle"


class LuAlignCenterHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignCenterHorizontal"


class LuAlignCenterVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignCenterVertical"


class LuAlignCenter(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignCenter"


class LuAlignEndHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignEndHorizontal"


class LuAlignEndVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignEndVertical"


class LuAlignHorizontalDistributeCenter(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalDistributeCenter"


class LuAlignHorizontalDistributeEnd(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalDistributeEnd"


class LuAlignHorizontalDistributeStart(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalDistributeStart"


class LuAlignHorizontalJustifyCenter(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalJustifyCenter"


class LuAlignHorizontalJustifyEnd(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalJustifyEnd"


class LuAlignHorizontalJustifyStart(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalJustifyStart"


class LuAlignHorizontalSpaceAround(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalSpaceAround"


class LuAlignHorizontalSpaceBetween(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignHorizontalSpaceBetween"


class LuAlignJustify(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignJustify"


class LuAlignLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignLeft"


class LuAlignRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignRight"


class LuAlignStartHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignStartHorizontal"


class LuAlignStartVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignStartVertical"


class LuAlignVerticalDistributeCenter(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalDistributeCenter"


class LuAlignVerticalDistributeEnd(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalDistributeEnd"


class LuAlignVerticalDistributeStart(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalDistributeStart"


class LuAlignVerticalJustifyCenter(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalJustifyCenter"


class LuAlignVerticalJustifyEnd(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalJustifyEnd"


class LuAlignVerticalJustifyStart(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalJustifyStart"


class LuAlignVerticalSpaceAround(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalSpaceAround"


class LuAlignVerticalSpaceBetween(rx.Component):
    library = "react-icons/lu"
    tag = "LuAlignVerticalSpaceBetween"


class LuAnchor(rx.Component):
    library = "react-icons/lu"
    tag = "LuAnchor"


class LuAngry(rx.Component):
    library = "react-icons/lu"
    tag = "LuAngry"


class LuAnnoyed(rx.Component):
    library = "react-icons/lu"
    tag = "LuAnnoyed"


class LuAperture(rx.Component):
    library = "react-icons/lu"
    tag = "LuAperture"


class LuAppWindow(rx.Component):
    library = "react-icons/lu"
    tag = "LuAppWindow"


class LuApple(rx.Component):
    library = "react-icons/lu"
    tag = "LuApple"


class LuArchiveRestore(rx.Component):
    library = "react-icons/lu"
    tag = "LuArchiveRestore"


class LuArchive(rx.Component):
    library = "react-icons/lu"
    tag = "LuArchive"


class LuArmchair(rx.Component):
    library = "react-icons/lu"
    tag = "LuArmchair"


class LuArrowBigDownDash(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigDownDash"


class LuArrowBigDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigDown"


class LuArrowBigLeftDash(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigLeftDash"


class LuArrowBigLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigLeft"


class LuArrowBigRightDash(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigRightDash"


class LuArrowBigRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigRight"


class LuArrowBigUpDash(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigUpDash"


class LuArrowBigUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowBigUp"


class LuArrowDown01(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDown01"


class LuArrowDown10(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDown10"


class LuArrowDownAZ(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownAZ"


class LuArrowDownCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownCircle"


class LuArrowDownLeftFromCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownLeftFromCircle"


class LuArrowDownLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownLeft"


class LuArrowDownNarrowWide(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownNarrowWide"


class LuArrowDownRightFromCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownRightFromCircle"


class LuArrowDownRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownRight"


class LuArrowDownSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownSquare"


class LuArrowDownUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownUp"


class LuArrowDownWideNarrow(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownWideNarrow"


class LuArrowDownZA(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDownZA"


class LuArrowDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowDown"


class LuArrowLeftCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowLeftCircle"


class LuArrowLeftRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowLeftRight"


class LuArrowLeftSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowLeftSquare"


class LuArrowLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowLeft"


class LuArrowRightCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowRightCircle"


class LuArrowRightLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowRightLeft"


class LuArrowRightSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowRightSquare"


class LuArrowRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowRight"


class LuArrowUp01(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUp01"


class LuArrowUp10(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUp10"


class LuArrowUpAZ(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpAZ"


class LuArrowUpCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpCircle"


class LuArrowUpDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpDown"


class LuArrowUpLeftFromCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpLeftFromCircle"


class LuArrowUpLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpLeft"


class LuArrowUpNarrowWide(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpNarrowWide"


class LuArrowUpRightFromCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpRightFromCircle"


class LuArrowUpRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpRight"


class LuArrowUpSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpSquare"


class LuArrowUpWideNarrow(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpWideNarrow"


class LuArrowUpZA(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUpZA"


class LuArrowUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuArrowUp"


class LuAsterisk(rx.Component):
    library = "react-icons/lu"
    tag = "LuAsterisk"


class LuAtSign(rx.Component):
    library = "react-icons/lu"
    tag = "LuAtSign"


class LuAtom(rx.Component):
    library = "react-icons/lu"
    tag = "LuAtom"


class LuAward(rx.Component):
    library = "react-icons/lu"
    tag = "LuAward"


class LuAxe(rx.Component):
    library = "react-icons/lu"
    tag = "LuAxe"


class LuAxis3D(rx.Component):
    library = "react-icons/lu"
    tag = "LuAxis3D"


class LuBaby(rx.Component):
    library = "react-icons/lu"
    tag = "LuBaby"


class LuBackpack(rx.Component):
    library = "react-icons/lu"
    tag = "LuBackpack"


class LuBaggageClaim(rx.Component):
    library = "react-icons/lu"
    tag = "LuBaggageClaim"


class LuBan(rx.Component):
    library = "react-icons/lu"
    tag = "LuBan"


class LuBanana(rx.Component):
    library = "react-icons/lu"
    tag = "LuBanana"


class LuBanknote(rx.Component):
    library = "react-icons/lu"
    tag = "LuBanknote"


class LuBarChart2(rx.Component):
    library = "react-icons/lu"
    tag = "LuBarChart2"


class LuBarChart3(rx.Component):
    library = "react-icons/lu"
    tag = "LuBarChart3"


class LuBarChart4(rx.Component):
    library = "react-icons/lu"
    tag = "LuBarChart4"


class LuBarChartHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuBarChartHorizontal"


class LuBarChart(rx.Component):
    library = "react-icons/lu"
    tag = "LuBarChart"


class LuBaseline(rx.Component):
    library = "react-icons/lu"
    tag = "LuBaseline"


class LuBath(rx.Component):
    library = "react-icons/lu"
    tag = "LuBath"


class LuBatteryCharging(rx.Component):
    library = "react-icons/lu"
    tag = "LuBatteryCharging"


class LuBatteryFull(rx.Component):
    library = "react-icons/lu"
    tag = "LuBatteryFull"


class LuBatteryLow(rx.Component):
    library = "react-icons/lu"
    tag = "LuBatteryLow"


class LuBatteryMedium(rx.Component):
    library = "react-icons/lu"
    tag = "LuBatteryMedium"


class LuBatteryWarning(rx.Component):
    library = "react-icons/lu"
    tag = "LuBatteryWarning"


class LuBattery(rx.Component):
    library = "react-icons/lu"
    tag = "LuBattery"


class LuBeaker(rx.Component):
    library = "react-icons/lu"
    tag = "LuBeaker"


class LuBeanOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuBeanOff"


class LuBean(rx.Component):
    library = "react-icons/lu"
    tag = "LuBean"


class LuBedDouble(rx.Component):
    library = "react-icons/lu"
    tag = "LuBedDouble"


class LuBedSingle(rx.Component):
    library = "react-icons/lu"
    tag = "LuBedSingle"


class LuBed(rx.Component):
    library = "react-icons/lu"
    tag = "LuBed"


class LuBeef(rx.Component):
    library = "react-icons/lu"
    tag = "LuBeef"


class LuBeer(rx.Component):
    library = "react-icons/lu"
    tag = "LuBeer"


class LuBellDot(rx.Component):
    library = "react-icons/lu"
    tag = "LuBellDot"


class LuBellMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuBellMinus"


class LuBellOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuBellOff"


class LuBellPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuBellPlus"


class LuBellRing(rx.Component):
    library = "react-icons/lu"
    tag = "LuBellRing"


class LuBell(rx.Component):
    library = "react-icons/lu"
    tag = "LuBell"


class LuBike(rx.Component):
    library = "react-icons/lu"
    tag = "LuBike"


class LuBinary(rx.Component):
    library = "react-icons/lu"
    tag = "LuBinary"


class LuBiohazard(rx.Component):
    library = "react-icons/lu"
    tag = "LuBiohazard"


class LuBird(rx.Component):
    library = "react-icons/lu"
    tag = "LuBird"


class LuBitcoin(rx.Component):
    library = "react-icons/lu"
    tag = "LuBitcoin"


class LuBlinds(rx.Component):
    library = "react-icons/lu"
    tag = "LuBlinds"


class LuBluetoothConnected(rx.Component):
    library = "react-icons/lu"
    tag = "LuBluetoothConnected"


class LuBluetoothOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuBluetoothOff"


class LuBluetoothSearching(rx.Component):
    library = "react-icons/lu"
    tag = "LuBluetoothSearching"


class LuBluetooth(rx.Component):
    library = "react-icons/lu"
    tag = "LuBluetooth"


class LuBold(rx.Component):
    library = "react-icons/lu"
    tag = "LuBold"


class LuBomb(rx.Component):
    library = "react-icons/lu"
    tag = "LuBomb"


class LuBone(rx.Component):
    library = "react-icons/lu"
    tag = "LuBone"


class LuBookCopy(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookCopy"


class LuBookDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookDown"


class LuBookKey(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookKey"


class LuBookLock(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookLock"


class LuBookMarked(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookMarked"


class LuBookMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookMinus"


class LuBookOpenCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookOpenCheck"


class LuBookOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookOpen"


class LuBookPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookPlus"


class LuBookTemplate(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookTemplate"


class LuBookUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookUp"


class LuBookX(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookX"


class LuBook(rx.Component):
    library = "react-icons/lu"
    tag = "LuBook"


class LuBookmarkMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookmarkMinus"


class LuBookmarkPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookmarkPlus"


class LuBookmark(rx.Component):
    library = "react-icons/lu"
    tag = "LuBookmark"


class LuBot(rx.Component):
    library = "react-icons/lu"
    tag = "LuBot"


class LuBoxSelect(rx.Component):
    library = "react-icons/lu"
    tag = "LuBoxSelect"


class LuBox(rx.Component):
    library = "react-icons/lu"
    tag = "LuBox"


class LuBoxes(rx.Component):
    library = "react-icons/lu"
    tag = "LuBoxes"


class LuBraces(rx.Component):
    library = "react-icons/lu"
    tag = "LuBraces"


class LuBrackets(rx.Component):
    library = "react-icons/lu"
    tag = "LuBrackets"


class LuBrainCircuit(rx.Component):
    library = "react-icons/lu"
    tag = "LuBrainCircuit"


class LuBrainCog(rx.Component):
    library = "react-icons/lu"
    tag = "LuBrainCog"


class LuBrain(rx.Component):
    library = "react-icons/lu"
    tag = "LuBrain"


class LuBriefcase(rx.Component):
    library = "react-icons/lu"
    tag = "LuBriefcase"


class LuBrush(rx.Component):
    library = "react-icons/lu"
    tag = "LuBrush"


class LuBug(rx.Component):
    library = "react-icons/lu"
    tag = "LuBug"


class LuBuilding2(rx.Component):
    library = "react-icons/lu"
    tag = "LuBuilding2"


class LuBuilding(rx.Component):
    library = "react-icons/lu"
    tag = "LuBuilding"


class LuBus(rx.Component):
    library = "react-icons/lu"
    tag = "LuBus"


class LuCake(rx.Component):
    library = "react-icons/lu"
    tag = "LuCake"


class LuCalculator(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalculator"


class LuCalendarCheck2(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarCheck2"


class LuCalendarCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarCheck"


class LuCalendarClock(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarClock"


class LuCalendarDays(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarDays"


class LuCalendarHeart(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarHeart"


class LuCalendarMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarMinus"


class LuCalendarOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarOff"


class LuCalendarPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarPlus"


class LuCalendarRange(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarRange"


class LuCalendarSearch(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarSearch"


class LuCalendarX2(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarX2"


class LuCalendarX(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendarX"


class LuCalendar(rx.Component):
    library = "react-icons/lu"
    tag = "LuCalendar"


class LuCameraOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuCameraOff"


class LuCamera(rx.Component):
    library = "react-icons/lu"
    tag = "LuCamera"


class LuCandyOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuCandyOff"


class LuCandy(rx.Component):
    library = "react-icons/lu"
    tag = "LuCandy"


class LuCar(rx.Component):
    library = "react-icons/lu"
    tag = "LuCar"


class LuCarrot(rx.Component):
    library = "react-icons/lu"
    tag = "LuCarrot"


class LuCaseLower(rx.Component):
    library = "react-icons/lu"
    tag = "LuCaseLower"


class LuCaseSensitive(rx.Component):
    library = "react-icons/lu"
    tag = "LuCaseSensitive"


class LuCaseUpper(rx.Component):
    library = "react-icons/lu"
    tag = "LuCaseUpper"


class LuCast(rx.Component):
    library = "react-icons/lu"
    tag = "LuCast"


class LuCastle(rx.Component):
    library = "react-icons/lu"
    tag = "LuCastle"


class LuCat(rx.Component):
    library = "react-icons/lu"
    tag = "LuCat"


class LuCheckCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuCheckCheck"


class LuCheckCircle2(rx.Component):
    library = "react-icons/lu"
    tag = "LuCheckCircle2"


class LuCheckCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuCheckCircle"


class LuCheckSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuCheckSquare"


class LuCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuCheck"


class LuChefHat(rx.Component):
    library = "react-icons/lu"
    tag = "LuChefHat"


class LuCherry(rx.Component):
    library = "react-icons/lu"
    tag = "LuCherry"


class LuChevronDownSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronDownSquare"


class LuChevronDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronDown"


class LuChevronFirst(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronFirst"


class LuChevronLast(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronLast"


class LuChevronLeftSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronLeftSquare"


class LuChevronLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronLeft"


class LuChevronRightSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronRightSquare"


class LuChevronRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronRight"


class LuChevronUpSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronUpSquare"


class LuChevronUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronUp"


class LuChevronsDownUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsDownUp"


class LuChevronsDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsDown"


class LuChevronsLeftRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsLeftRight"


class LuChevronsLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsLeft"


class LuChevronsRightLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsRightLeft"


class LuChevronsRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsRight"


class LuChevronsUpDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsUpDown"


class LuChevronsUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuChevronsUp"


class LuChrome(rx.Component):
    library = "react-icons/lu"
    tag = "LuChrome"


class LuChurch(rx.Component):
    library = "react-icons/lu"
    tag = "LuChurch"


class LuCigaretteOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuCigaretteOff"


class LuCigarette(rx.Component):
    library = "react-icons/lu"
    tag = "LuCigarette"


class LuCircleDot(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircleDot"


class LuCircleEllipsis(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircleEllipsis"


class LuCircleEqual(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircleEqual"


class LuCircleOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircleOff"


class LuCircleSlash2(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircleSlash2"


class LuCircleSlash(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircleSlash"


class LuCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircle"


class LuCircuitBoard(rx.Component):
    library = "react-icons/lu"
    tag = "LuCircuitBoard"


class LuCitrus(rx.Component):
    library = "react-icons/lu"
    tag = "LuCitrus"


class LuClapperboard(rx.Component):
    library = "react-icons/lu"
    tag = "LuClapperboard"


class LuClipboardCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardCheck"


class LuClipboardCopy(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardCopy"


class LuClipboardEdit(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardEdit"


class LuClipboardList(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardList"


class LuClipboardPaste(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardPaste"


class LuClipboardSignature(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardSignature"


class LuClipboardType(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardType"


class LuClipboardX(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboardX"


class LuClipboard(rx.Component):
    library = "react-icons/lu"
    tag = "LuClipboard"


class LuClock1(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock1"


class LuClock10(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock10"


class LuClock11(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock11"


class LuClock12(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock12"


class LuClock2(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock2"


class LuClock3(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock3"


class LuClock4(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock4"


class LuClock5(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock5"


class LuClock6(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock6"


class LuClock7(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock7"


class LuClock8(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock8"


class LuClock9(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock9"


class LuClock(rx.Component):
    library = "react-icons/lu"
    tag = "LuClock"


class LuCloudCog(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudCog"


class LuCloudDrizzle(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudDrizzle"


class LuCloudFog(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudFog"


class LuCloudHail(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudHail"


class LuCloudLightning(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudLightning"


class LuCloudMoonRain(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudMoonRain"


class LuCloudMoon(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudMoon"


class LuCloudOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudOff"


class LuCloudRainWind(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudRainWind"


class LuCloudRain(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudRain"


class LuCloudSnow(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudSnow"


class LuCloudSunRain(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudSunRain"


class LuCloudSun(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudSun"


class LuCloud(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloud"


class LuCloudy(rx.Component):
    library = "react-icons/lu"
    tag = "LuCloudy"


class LuClover(rx.Component):
    library = "react-icons/lu"
    tag = "LuClover"


class LuCode2(rx.Component):
    library = "react-icons/lu"
    tag = "LuCode2"


class LuCode(rx.Component):
    library = "react-icons/lu"
    tag = "LuCode"


class LuCodepen(rx.Component):
    library = "react-icons/lu"
    tag = "LuCodepen"


class LuCodesandbox(rx.Component):
    library = "react-icons/lu"
    tag = "LuCodesandbox"


class LuCoffee(rx.Component):
    library = "react-icons/lu"
    tag = "LuCoffee"


class LuCog(rx.Component):
    library = "react-icons/lu"
    tag = "LuCog"


class LuCoins(rx.Component):
    library = "react-icons/lu"
    tag = "LuCoins"


class LuColumns(rx.Component):
    library = "react-icons/lu"
    tag = "LuColumns"


class LuCommand(rx.Component):
    library = "react-icons/lu"
    tag = "LuCommand"


class LuCompass(rx.Component):
    library = "react-icons/lu"
    tag = "LuCompass"


class LuComponent(rx.Component):
    library = "react-icons/lu"
    tag = "LuComponent"


class LuConciergeBell(rx.Component):
    library = "react-icons/lu"
    tag = "LuConciergeBell"


class LuConstruction(rx.Component):
    library = "react-icons/lu"
    tag = "LuConstruction"


class LuContact(rx.Component):
    library = "react-icons/lu"
    tag = "LuContact"


class LuContrast(rx.Component):
    library = "react-icons/lu"
    tag = "LuContrast"


class LuCookie(rx.Component):
    library = "react-icons/lu"
    tag = "LuCookie"


class LuCopyCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopyCheck"


class LuCopyMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopyMinus"


class LuCopyPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopyPlus"


class LuCopySlash(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopySlash"


class LuCopyX(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopyX"


class LuCopy(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopy"


class LuCopyleft(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopyleft"


class LuCopyright(rx.Component):
    library = "react-icons/lu"
    tag = "LuCopyright"


class LuCornerDownLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerDownLeft"


class LuCornerDownRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerDownRight"


class LuCornerLeftDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerLeftDown"


class LuCornerLeftUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerLeftUp"


class LuCornerRightDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerRightDown"


class LuCornerRightUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerRightUp"


class LuCornerUpLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerUpLeft"


class LuCornerUpRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuCornerUpRight"


class LuCpu(rx.Component):
    library = "react-icons/lu"
    tag = "LuCpu"


class LuCreativeCommons(rx.Component):
    library = "react-icons/lu"
    tag = "LuCreativeCommons"


class LuCreditCard(rx.Component):
    library = "react-icons/lu"
    tag = "LuCreditCard"


class LuCroissant(rx.Component):
    library = "react-icons/lu"
    tag = "LuCroissant"


class LuCrop(rx.Component):
    library = "react-icons/lu"
    tag = "LuCrop"


class LuCross(rx.Component):
    library = "react-icons/lu"
    tag = "LuCross"


class LuCrosshair(rx.Component):
    library = "react-icons/lu"
    tag = "LuCrosshair"


class LuCrown(rx.Component):
    library = "react-icons/lu"
    tag = "LuCrown"


class LuCupSoda(rx.Component):
    library = "react-icons/lu"
    tag = "LuCupSoda"


class LuCurrency(rx.Component):
    library = "react-icons/lu"
    tag = "LuCurrency"


class LuDatabaseBackup(rx.Component):
    library = "react-icons/lu"
    tag = "LuDatabaseBackup"


class LuDatabase(rx.Component):
    library = "react-icons/lu"
    tag = "LuDatabase"


class LuDelete(rx.Component):
    library = "react-icons/lu"
    tag = "LuDelete"


class LuDiamond(rx.Component):
    library = "react-icons/lu"
    tag = "LuDiamond"


class LuDice1(rx.Component):
    library = "react-icons/lu"
    tag = "LuDice1"


class LuDice2(rx.Component):
    library = "react-icons/lu"
    tag = "LuDice2"


class LuDice3(rx.Component):
    library = "react-icons/lu"
    tag = "LuDice3"


class LuDice4(rx.Component):
    library = "react-icons/lu"
    tag = "LuDice4"


class LuDice5(rx.Component):
    library = "react-icons/lu"
    tag = "LuDice5"


class LuDice6(rx.Component):
    library = "react-icons/lu"
    tag = "LuDice6"


class LuDices(rx.Component):
    library = "react-icons/lu"
    tag = "LuDices"


class LuDiff(rx.Component):
    library = "react-icons/lu"
    tag = "LuDiff"


class LuDisc2(rx.Component):
    library = "react-icons/lu"
    tag = "LuDisc2"


class LuDisc(rx.Component):
    library = "react-icons/lu"
    tag = "LuDisc"


class LuDivideCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuDivideCircle"


class LuDivideSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuDivideSquare"


class LuDivide(rx.Component):
    library = "react-icons/lu"
    tag = "LuDivide"


class LuDnaOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuDnaOff"


class LuDna(rx.Component):
    library = "react-icons/lu"
    tag = "LuDna"


class LuDog(rx.Component):
    library = "react-icons/lu"
    tag = "LuDog"


class LuDollarSign(rx.Component):
    library = "react-icons/lu"
    tag = "LuDollarSign"


class LuDoorClosed(rx.Component):
    library = "react-icons/lu"
    tag = "LuDoorClosed"


class LuDoorOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuDoorOpen"


class LuDownloadCloud(rx.Component):
    library = "react-icons/lu"
    tag = "LuDownloadCloud"


class LuDownload(rx.Component):
    library = "react-icons/lu"
    tag = "LuDownload"


class LuDribbble(rx.Component):
    library = "react-icons/lu"
    tag = "LuDribbble"


class LuDroplet(rx.Component):
    library = "react-icons/lu"
    tag = "LuDroplet"


class LuDroplets(rx.Component):
    library = "react-icons/lu"
    tag = "LuDroplets"


class LuDrumstick(rx.Component):
    library = "react-icons/lu"
    tag = "LuDrumstick"


class LuDumbbell(rx.Component):
    library = "react-icons/lu"
    tag = "LuDumbbell"


class LuEarOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuEarOff"


class LuEar(rx.Component):
    library = "react-icons/lu"
    tag = "LuEar"


class LuEdit2(rx.Component):
    library = "react-icons/lu"
    tag = "LuEdit2"


class LuEdit3(rx.Component):
    library = "react-icons/lu"
    tag = "LuEdit3"


class LuEdit(rx.Component):
    library = "react-icons/lu"
    tag = "LuEdit"


class LuEggFried(rx.Component):
    library = "react-icons/lu"
    tag = "LuEggFried"


class LuEggOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuEggOff"


class LuEgg(rx.Component):
    library = "react-icons/lu"
    tag = "LuEgg"


class LuEqualNot(rx.Component):
    library = "react-icons/lu"
    tag = "LuEqualNot"


class LuEqual(rx.Component):
    library = "react-icons/lu"
    tag = "LuEqual"


class LuEraser(rx.Component):
    library = "react-icons/lu"
    tag = "LuEraser"


class LuEuro(rx.Component):
    library = "react-icons/lu"
    tag = "LuEuro"


class LuExpand(rx.Component):
    library = "react-icons/lu"
    tag = "LuExpand"


class LuExternalLink(rx.Component):
    library = "react-icons/lu"
    tag = "LuExternalLink"


class LuEyeOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuEyeOff"


class LuEye(rx.Component):
    library = "react-icons/lu"
    tag = "LuEye"


class LuFacebook(rx.Component):
    library = "react-icons/lu"
    tag = "LuFacebook"


class LuFactory(rx.Component):
    library = "react-icons/lu"
    tag = "LuFactory"


class LuFan(rx.Component):
    library = "react-icons/lu"
    tag = "LuFan"


class LuFastForward(rx.Component):
    library = "react-icons/lu"
    tag = "LuFastForward"


class LuFeather(rx.Component):
    library = "react-icons/lu"
    tag = "LuFeather"


class LuFigma(rx.Component):
    library = "react-icons/lu"
    tag = "LuFigma"


class LuFileArchive(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileArchive"


class LuFileAudio2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileAudio2"


class LuFileAudio(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileAudio"


class LuFileAxis3D(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileAxis3D"


class LuFileBadge2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileBadge2"


class LuFileBadge(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileBadge"


class LuFileBarChart2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileBarChart2"


class LuFileBarChart(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileBarChart"


class LuFileBox(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileBox"


class LuFileCheck2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileCheck2"


class LuFileCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileCheck"


class LuFileClock(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileClock"


class LuFileCode(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileCode"


class LuFileCog2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileCog2"


class LuFileCog(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileCog"


class LuFileDiff(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileDiff"


class LuFileDigit(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileDigit"


class LuFileDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileDown"


class LuFileEdit(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileEdit"


class LuFileHeart(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileHeart"


class LuFileImage(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileImage"


class LuFileInput(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileInput"


class LuFileJson2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileJson2"


class LuFileJson(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileJson"


class LuFileKey2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileKey2"


class LuFileKey(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileKey"


class LuFileLineChart(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileLineChart"


class LuFileLock2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileLock2"


class LuFileLock(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileLock"


class LuFileMinus2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileMinus2"


class LuFileMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileMinus"


class LuFileOutput(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileOutput"


class LuFilePieChart(rx.Component):
    library = "react-icons/lu"
    tag = "LuFilePieChart"


class LuFilePlus2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFilePlus2"


class LuFilePlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuFilePlus"


class LuFileQuestion(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileQuestion"


class LuFileScan(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileScan"


class LuFileSearch2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileSearch2"


class LuFileSearch(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileSearch"


class LuFileSignature(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileSignature"


class LuFileSpreadsheet(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileSpreadsheet"


class LuFileSymlink(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileSymlink"


class LuFileTerminal(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileTerminal"


class LuFileText(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileText"


class LuFileType2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileType2"


class LuFileType(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileType"


class LuFileUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileUp"


class LuFileVideo2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileVideo2"


class LuFileVideo(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileVideo"


class LuFileVolume2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileVolume2"


class LuFileVolume(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileVolume"


class LuFileWarning(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileWarning"


class LuFileX2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileX2"


class LuFileX(rx.Component):
    library = "react-icons/lu"
    tag = "LuFileX"


class LuFile(rx.Component):
    library = "react-icons/lu"
    tag = "LuFile"


class LuFiles(rx.Component):
    library = "react-icons/lu"
    tag = "LuFiles"


class LuFilm(rx.Component):
    library = "react-icons/lu"
    tag = "LuFilm"


class LuFilterX(rx.Component):
    library = "react-icons/lu"
    tag = "LuFilterX"


class LuFilter(rx.Component):
    library = "react-icons/lu"
    tag = "LuFilter"


class LuFingerprint(rx.Component):
    library = "react-icons/lu"
    tag = "LuFingerprint"


class LuFishOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuFishOff"


class LuFish(rx.Component):
    library = "react-icons/lu"
    tag = "LuFish"


class LuFlagOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlagOff"


class LuFlagTriangleLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlagTriangleLeft"


class LuFlagTriangleRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlagTriangleRight"


class LuFlag(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlag"


class LuFlame(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlame"


class LuFlashlightOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlashlightOff"


class LuFlashlight(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlashlight"


class LuFlaskConicalOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlaskConicalOff"


class LuFlaskConical(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlaskConical"


class LuFlaskRound(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlaskRound"


class LuFlipHorizontal2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlipHorizontal2"


class LuFlipHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlipHorizontal"


class LuFlipVertical2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlipVertical2"


class LuFlipVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlipVertical"


class LuFlower2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlower2"


class LuFlower(rx.Component):
    library = "react-icons/lu"
    tag = "LuFlower"


class LuFocus(rx.Component):
    library = "react-icons/lu"
    tag = "LuFocus"


class LuFoldHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuFoldHorizontal"


class LuFoldVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuFoldVertical"


class LuFolderArchive(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderArchive"


class LuFolderCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderCheck"


class LuFolderClock(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderClock"


class LuFolderClosed(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderClosed"


class LuFolderCog2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderCog2"


class LuFolderCog(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderCog"


class LuFolderDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderDown"


class LuFolderEdit(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderEdit"


class LuFolderGit2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderGit2"


class LuFolderGit(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderGit"


class LuFolderHeart(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderHeart"


class LuFolderInput(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderInput"


class LuFolderKey(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderKey"


class LuFolderLock(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderLock"


class LuFolderMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderMinus"


class LuFolderOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderOpen"


class LuFolderOutput(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderOutput"


class LuFolderPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderPlus"


class LuFolderSearch2(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderSearch2"


class LuFolderSearch(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderSearch"


class LuFolderSymlink(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderSymlink"


class LuFolderTree(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderTree"


class LuFolderUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderUp"


class LuFolderX(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolderX"


class LuFolder(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolder"


class LuFolders(rx.Component):
    library = "react-icons/lu"
    tag = "LuFolders"


class LuFootprints(rx.Component):
    library = "react-icons/lu"
    tag = "LuFootprints"


class LuForklift(rx.Component):
    library = "react-icons/lu"
    tag = "LuForklift"


class LuFormInput(rx.Component):
    library = "react-icons/lu"
    tag = "LuFormInput"


class LuForward(rx.Component):
    library = "react-icons/lu"
    tag = "LuForward"


class LuFrame(rx.Component):
    library = "react-icons/lu"
    tag = "LuFrame"


class LuFramer(rx.Component):
    library = "react-icons/lu"
    tag = "LuFramer"


class LuFrown(rx.Component):
    library = "react-icons/lu"
    tag = "LuFrown"


class LuFuel(rx.Component):
    library = "react-icons/lu"
    tag = "LuFuel"


class LuFunctionSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuFunctionSquare"


class LuGamepad2(rx.Component):
    library = "react-icons/lu"
    tag = "LuGamepad2"


class LuGamepad(rx.Component):
    library = "react-icons/lu"
    tag = "LuGamepad"


class LuGauge(rx.Component):
    library = "react-icons/lu"
    tag = "LuGauge"


class LuGavel(rx.Component):
    library = "react-icons/lu"
    tag = "LuGavel"


class LuGem(rx.Component):
    library = "react-icons/lu"
    tag = "LuGem"


class LuGhost(rx.Component):
    library = "react-icons/lu"
    tag = "LuGhost"


class LuGift(rx.Component):
    library = "react-icons/lu"
    tag = "LuGift"


class LuGitBranchPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitBranchPlus"


class LuGitBranch(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitBranch"


class LuGitCommit(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitCommit"


class LuGitCompare(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitCompare"


class LuGitFork(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitFork"


class LuGitMerge(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitMerge"


class LuGitPullRequestClosed(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitPullRequestClosed"


class LuGitPullRequestDraft(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitPullRequestDraft"


class LuGitPullRequest(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitPullRequest"


class LuGithub(rx.Component):
    library = "react-icons/lu"
    tag = "LuGithub"


class LuGitlab(rx.Component):
    library = "react-icons/lu"
    tag = "LuGitlab"


class LuGlassWater(rx.Component):
    library = "react-icons/lu"
    tag = "LuGlassWater"


class LuGlasses(rx.Component):
    library = "react-icons/lu"
    tag = "LuGlasses"


class LuGlobe2(rx.Component):
    library = "react-icons/lu"
    tag = "LuGlobe2"


class LuGlobe(rx.Component):
    library = "react-icons/lu"
    tag = "LuGlobe"


class LuGrab(rx.Component):
    library = "react-icons/lu"
    tag = "LuGrab"


class LuGraduationCap(rx.Component):
    library = "react-icons/lu"
    tag = "LuGraduationCap"


class LuGrape(rx.Component):
    library = "react-icons/lu"
    tag = "LuGrape"


class LuGrid(rx.Component):
    library = "react-icons/lu"
    tag = "LuGrid"


class LuGripHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuGripHorizontal"


class LuGripVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuGripVertical"


class LuGrip(rx.Component):
    library = "react-icons/lu"
    tag = "LuGrip"


class LuHammer(rx.Component):
    library = "react-icons/lu"
    tag = "LuHammer"


class LuHandMetal(rx.Component):
    library = "react-icons/lu"
    tag = "LuHandMetal"


class LuHand(rx.Component):
    library = "react-icons/lu"
    tag = "LuHand"


class LuHardDrive(rx.Component):
    library = "react-icons/lu"
    tag = "LuHardDrive"


class LuHardHat(rx.Component):
    library = "react-icons/lu"
    tag = "LuHardHat"


class LuHash(rx.Component):
    library = "react-icons/lu"
    tag = "LuHash"


class LuHaze(rx.Component):
    library = "react-icons/lu"
    tag = "LuHaze"


class LuHeading1(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeading1"


class LuHeading2(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeading2"


class LuHeading3(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeading3"


class LuHeading4(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeading4"


class LuHeading5(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeading5"


class LuHeading6(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeading6"


class LuHeading(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeading"


class LuHeadphones(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeadphones"


class LuHeartCrack(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeartCrack"


class LuHeartHandshake(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeartHandshake"


class LuHeartOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeartOff"


class LuHeartPulse(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeartPulse"


class LuHeart(rx.Component):
    library = "react-icons/lu"
    tag = "LuHeart"


class LuHelpCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuHelpCircle"


class LuHelpingHand(rx.Component):
    library = "react-icons/lu"
    tag = "LuHelpingHand"


class LuHexagon(rx.Component):
    library = "react-icons/lu"
    tag = "LuHexagon"


class LuHighlighter(rx.Component):
    library = "react-icons/lu"
    tag = "LuHighlighter"


class LuHistory(rx.Component):
    library = "react-icons/lu"
    tag = "LuHistory"


class LuHome(rx.Component):
    library = "react-icons/lu"
    tag = "LuHome"


class LuHopOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuHopOff"


class LuHop(rx.Component):
    library = "react-icons/lu"
    tag = "LuHop"


class LuHotel(rx.Component):
    library = "react-icons/lu"
    tag = "LuHotel"


class LuHourglass(rx.Component):
    library = "react-icons/lu"
    tag = "LuHourglass"


class LuIceCream2(rx.Component):
    library = "react-icons/lu"
    tag = "LuIceCream2"


class LuIceCream(rx.Component):
    library = "react-icons/lu"
    tag = "LuIceCream"


class LuImageMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuImageMinus"


class LuImageOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuImageOff"


class LuImagePlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuImagePlus"


class LuImage(rx.Component):
    library = "react-icons/lu"
    tag = "LuImage"


class LuImport(rx.Component):
    library = "react-icons/lu"
    tag = "LuImport"


class LuInbox(rx.Component):
    library = "react-icons/lu"
    tag = "LuInbox"


class LuIndent(rx.Component):
    library = "react-icons/lu"
    tag = "LuIndent"


class LuIndianRupee(rx.Component):
    library = "react-icons/lu"
    tag = "LuIndianRupee"


class LuInfinity(rx.Component):
    library = "react-icons/lu"
    tag = "LuInfinity"


class LuInfo(rx.Component):
    library = "react-icons/lu"
    tag = "LuInfo"


class LuInspect(rx.Component):
    library = "react-icons/lu"
    tag = "LuInspect"


class LuInstagram(rx.Component):
    library = "react-icons/lu"
    tag = "LuInstagram"


class LuItalic(rx.Component):
    library = "react-icons/lu"
    tag = "LuItalic"


class LuIterationCcw(rx.Component):
    library = "react-icons/lu"
    tag = "LuIterationCcw"


class LuIterationCw(rx.Component):
    library = "react-icons/lu"
    tag = "LuIterationCw"


class LuJapaneseYen(rx.Component):
    library = "react-icons/lu"
    tag = "LuJapaneseYen"


class LuJoystick(rx.Component):
    library = "react-icons/lu"
    tag = "LuJoystick"


class LuKey(rx.Component):
    library = "react-icons/lu"
    tag = "LuKey"


class LuKeyboard(rx.Component):
    library = "react-icons/lu"
    tag = "LuKeyboard"


class LuLampCeiling(rx.Component):
    library = "react-icons/lu"
    tag = "LuLampCeiling"


class LuLampDesk(rx.Component):
    library = "react-icons/lu"
    tag = "LuLampDesk"


class LuLampFloor(rx.Component):
    library = "react-icons/lu"
    tag = "LuLampFloor"


class LuLampWallDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuLampWallDown"


class LuLampWallUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuLampWallUp"


class LuLamp(rx.Component):
    library = "react-icons/lu"
    tag = "LuLamp"


class LuLandmark(rx.Component):
    library = "react-icons/lu"
    tag = "LuLandmark"


class LuLanguages(rx.Component):
    library = "react-icons/lu"
    tag = "LuLanguages"


class LuLaptop2(rx.Component):
    library = "react-icons/lu"
    tag = "LuLaptop2"


class LuLaptop(rx.Component):
    library = "react-icons/lu"
    tag = "LuLaptop"


class LuLassoSelect(rx.Component):
    library = "react-icons/lu"
    tag = "LuLassoSelect"


class LuLasso(rx.Component):
    library = "react-icons/lu"
    tag = "LuLasso"


class LuLaugh(rx.Component):
    library = "react-icons/lu"
    tag = "LuLaugh"


class LuLayers(rx.Component):
    library = "react-icons/lu"
    tag = "LuLayers"


class LuLayoutDashboard(rx.Component):
    library = "react-icons/lu"
    tag = "LuLayoutDashboard"


class LuLayoutGrid(rx.Component):
    library = "react-icons/lu"
    tag = "LuLayoutGrid"


class LuLayoutList(rx.Component):
    library = "react-icons/lu"
    tag = "LuLayoutList"


class LuLayoutTemplate(rx.Component):
    library = "react-icons/lu"
    tag = "LuLayoutTemplate"


class LuLayout(rx.Component):
    library = "react-icons/lu"
    tag = "LuLayout"


class LuLeaf(rx.Component):
    library = "react-icons/lu"
    tag = "LuLeaf"


class LuLibrary(rx.Component):
    library = "react-icons/lu"
    tag = "LuLibrary"


class LuLifeBuoy(rx.Component):
    library = "react-icons/lu"
    tag = "LuLifeBuoy"


class LuLigature(rx.Component):
    library = "react-icons/lu"
    tag = "LuLigature"


class LuLightbulbOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuLightbulbOff"


class LuLightbulb(rx.Component):
    library = "react-icons/lu"
    tag = "LuLightbulb"


class LuLineChart(rx.Component):
    library = "react-icons/lu"
    tag = "LuLineChart"


class LuLink2Off(rx.Component):
    library = "react-icons/lu"
    tag = "LuLink2Off"


class LuLink2(rx.Component):
    library = "react-icons/lu"
    tag = "LuLink2"


class LuLink(rx.Component):
    library = "react-icons/lu"
    tag = "LuLink"


class LuLinkedin(rx.Component):
    library = "react-icons/lu"
    tag = "LuLinkedin"


class LuListChecks(rx.Component):
    library = "react-icons/lu"
    tag = "LuListChecks"


class LuListEnd(rx.Component):
    library = "react-icons/lu"
    tag = "LuListEnd"


class LuListMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuListMinus"


class LuListMusic(rx.Component):
    library = "react-icons/lu"
    tag = "LuListMusic"


class LuListOrdered(rx.Component):
    library = "react-icons/lu"
    tag = "LuListOrdered"


class LuListPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuListPlus"


class LuListStart(rx.Component):
    library = "react-icons/lu"
    tag = "LuListStart"


class LuListTree(rx.Component):
    library = "react-icons/lu"
    tag = "LuListTree"


class LuListVideo(rx.Component):
    library = "react-icons/lu"
    tag = "LuListVideo"


class LuListX(rx.Component):
    library = "react-icons/lu"
    tag = "LuListX"


class LuList(rx.Component):
    library = "react-icons/lu"
    tag = "LuList"


class LuLoader2(rx.Component):
    library = "react-icons/lu"
    tag = "LuLoader2"


class LuLoader(rx.Component):
    library = "react-icons/lu"
    tag = "LuLoader"


class LuLocateFixed(rx.Component):
    library = "react-icons/lu"
    tag = "LuLocateFixed"


class LuLocateOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuLocateOff"


class LuLocate(rx.Component):
    library = "react-icons/lu"
    tag = "LuLocate"


class LuLock(rx.Component):
    library = "react-icons/lu"
    tag = "LuLock"


class LuLogIn(rx.Component):
    library = "react-icons/lu"
    tag = "LuLogIn"


class LuLogOut(rx.Component):
    library = "react-icons/lu"
    tag = "LuLogOut"


class LuLuggage(rx.Component):
    library = "react-icons/lu"
    tag = "LuLuggage"


class LuMagnet(rx.Component):
    library = "react-icons/lu"
    tag = "LuMagnet"


class LuMailCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailCheck"


class LuMailMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailMinus"


class LuMailOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailOpen"


class LuMailPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailPlus"


class LuMailQuestion(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailQuestion"


class LuMailSearch(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailSearch"


class LuMailWarning(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailWarning"


class LuMailX(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailX"


class LuMail(rx.Component):
    library = "react-icons/lu"
    tag = "LuMail"


class LuMailbox(rx.Component):
    library = "react-icons/lu"
    tag = "LuMailbox"


class LuMails(rx.Component):
    library = "react-icons/lu"
    tag = "LuMails"


class LuMapPinOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuMapPinOff"


class LuMapPin(rx.Component):
    library = "react-icons/lu"
    tag = "LuMapPin"


class LuMap(rx.Component):
    library = "react-icons/lu"
    tag = "LuMap"


class LuMartini(rx.Component):
    library = "react-icons/lu"
    tag = "LuMartini"


class LuMaximize2(rx.Component):
    library = "react-icons/lu"
    tag = "LuMaximize2"


class LuMaximize(rx.Component):
    library = "react-icons/lu"
    tag = "LuMaximize"


class LuMedal(rx.Component):
    library = "react-icons/lu"
    tag = "LuMedal"


class LuMegaphoneOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuMegaphoneOff"


class LuMegaphone(rx.Component):
    library = "react-icons/lu"
    tag = "LuMegaphone"


class LuMeh(rx.Component):
    library = "react-icons/lu"
    tag = "LuMeh"


class LuMemoryStick(rx.Component):
    library = "react-icons/lu"
    tag = "LuMemoryStick"


class LuMenu(rx.Component):
    library = "react-icons/lu"
    tag = "LuMenu"


class LuMerge(rx.Component):
    library = "react-icons/lu"
    tag = "LuMerge"


class LuMessageCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuMessageCircle"


class LuMessageSquareDashed(rx.Component):
    library = "react-icons/lu"
    tag = "LuMessageSquareDashed"


class LuMessageSquarePlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuMessageSquarePlus"


class LuMessageSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuMessageSquare"


class LuMessagesSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuMessagesSquare"


class LuMic2(rx.Component):
    library = "react-icons/lu"
    tag = "LuMic2"


class LuMicOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuMicOff"


class LuMic(rx.Component):
    library = "react-icons/lu"
    tag = "LuMic"


class LuMicroscope(rx.Component):
    library = "react-icons/lu"
    tag = "LuMicroscope"


class LuMicrowave(rx.Component):
    library = "react-icons/lu"
    tag = "LuMicrowave"


class LuMilestone(rx.Component):
    library = "react-icons/lu"
    tag = "LuMilestone"


class LuMilkOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuMilkOff"


class LuMilk(rx.Component):
    library = "react-icons/lu"
    tag = "LuMilk"


class LuMinimize2(rx.Component):
    library = "react-icons/lu"
    tag = "LuMinimize2"


class LuMinimize(rx.Component):
    library = "react-icons/lu"
    tag = "LuMinimize"


class LuMinusCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuMinusCircle"


class LuMinusSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuMinusSquare"


class LuMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuMinus"


class LuMonitorDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuMonitorDown"


class LuMonitorOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuMonitorOff"


class LuMonitorSmartphone(rx.Component):
    library = "react-icons/lu"
    tag = "LuMonitorSmartphone"


class LuMonitorSpeaker(rx.Component):
    library = "react-icons/lu"
    tag = "LuMonitorSpeaker"


class LuMonitorUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuMonitorUp"


class LuMonitor(rx.Component):
    library = "react-icons/lu"
    tag = "LuMonitor"


class LuMoonStar(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoonStar"


class LuMoon(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoon"


class LuMoreHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoreHorizontal"


class LuMoreVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoreVertical"


class LuMountainSnow(rx.Component):
    library = "react-icons/lu"
    tag = "LuMountainSnow"


class LuMountain(rx.Component):
    library = "react-icons/lu"
    tag = "LuMountain"


class LuMousePointer2(rx.Component):
    library = "react-icons/lu"
    tag = "LuMousePointer2"


class LuMousePointerClick(rx.Component):
    library = "react-icons/lu"
    tag = "LuMousePointerClick"


class LuMousePointer(rx.Component):
    library = "react-icons/lu"
    tag = "LuMousePointer"


class LuMouse(rx.Component):
    library = "react-icons/lu"
    tag = "LuMouse"


class LuMove3D(rx.Component):
    library = "react-icons/lu"
    tag = "LuMove3D"


class LuMoveDiagonal2(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoveDiagonal2"


class LuMoveDiagonal(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoveDiagonal"


class LuMoveHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoveHorizontal"


class LuMoveVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuMoveVertical"


class LuMove(rx.Component):
    library = "react-icons/lu"
    tag = "LuMove"


class LuMusic2(rx.Component):
    library = "react-icons/lu"
    tag = "LuMusic2"


class LuMusic3(rx.Component):
    library = "react-icons/lu"
    tag = "LuMusic3"


class LuMusic4(rx.Component):
    library = "react-icons/lu"
    tag = "LuMusic4"


class LuMusic(rx.Component):
    library = "react-icons/lu"
    tag = "LuMusic"


class LuNavigation2Off(rx.Component):
    library = "react-icons/lu"
    tag = "LuNavigation2Off"


class LuNavigation2(rx.Component):
    library = "react-icons/lu"
    tag = "LuNavigation2"


class LuNavigationOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuNavigationOff"


class LuNavigation(rx.Component):
    library = "react-icons/lu"
    tag = "LuNavigation"


class LuNetwork(rx.Component):
    library = "react-icons/lu"
    tag = "LuNetwork"


class LuNewspaper(rx.Component):
    library = "react-icons/lu"
    tag = "LuNewspaper"


class LuNfc(rx.Component):
    library = "react-icons/lu"
    tag = "LuNfc"


class LuNutOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuNutOff"


class LuNut(rx.Component):
    library = "react-icons/lu"
    tag = "LuNut"


class LuOctagon(rx.Component):
    library = "react-icons/lu"
    tag = "LuOctagon"


class LuOption(rx.Component):
    library = "react-icons/lu"
    tag = "LuOption"


class LuOrbit(rx.Component):
    library = "react-icons/lu"
    tag = "LuOrbit"


class LuOutdent(rx.Component):
    library = "react-icons/lu"
    tag = "LuOutdent"


class LuPackage2(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackage2"


class LuPackageCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackageCheck"


class LuPackageMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackageMinus"


class LuPackageOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackageOpen"


class LuPackagePlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackagePlus"


class LuPackageSearch(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackageSearch"


class LuPackageX(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackageX"


class LuPackage(rx.Component):
    library = "react-icons/lu"
    tag = "LuPackage"


class LuPaintBucket(rx.Component):
    library = "react-icons/lu"
    tag = "LuPaintBucket"


class LuPaintbrush2(rx.Component):
    library = "react-icons/lu"
    tag = "LuPaintbrush2"


class LuPaintbrush(rx.Component):
    library = "react-icons/lu"
    tag = "LuPaintbrush"


class LuPalette(rx.Component):
    library = "react-icons/lu"
    tag = "LuPalette"


class LuPalmtree(rx.Component):
    library = "react-icons/lu"
    tag = "LuPalmtree"


class LuPanelBottomClose(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelBottomClose"


class LuPanelBottomInactive(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelBottomInactive"


class LuPanelBottomOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelBottomOpen"


class LuPanelBottom(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelBottom"


class LuPanelLeftClose(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelLeftClose"


class LuPanelLeftInactive(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelLeftInactive"


class LuPanelLeftOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelLeftOpen"


class LuPanelLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelLeft"


class LuPanelRightClose(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelRightClose"


class LuPanelRightInactive(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelRightInactive"


class LuPanelRightOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelRightOpen"


class LuPanelRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelRight"


class LuPanelTopClose(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelTopClose"


class LuPanelTopInactive(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelTopInactive"


class LuPanelTopOpen(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelTopOpen"


class LuPanelTop(rx.Component):
    library = "react-icons/lu"
    tag = "LuPanelTop"


class LuPaperclip(rx.Component):
    library = "react-icons/lu"
    tag = "LuPaperclip"


class LuParentheses(rx.Component):
    library = "react-icons/lu"
    tag = "LuParentheses"


class LuParkingCircleOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuParkingCircleOff"


class LuParkingCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuParkingCircle"


class LuParkingSquareOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuParkingSquareOff"


class LuParkingSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuParkingSquare"


class LuPartyPopper(rx.Component):
    library = "react-icons/lu"
    tag = "LuPartyPopper"


class LuPauseCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuPauseCircle"


class LuPauseOctagon(rx.Component):
    library = "react-icons/lu"
    tag = "LuPauseOctagon"


class LuPause(rx.Component):
    library = "react-icons/lu"
    tag = "LuPause"


class LuPcCase(rx.Component):
    library = "react-icons/lu"
    tag = "LuPcCase"


class LuPenTool(rx.Component):
    library = "react-icons/lu"
    tag = "LuPenTool"


class LuPencil(rx.Component):
    library = "react-icons/lu"
    tag = "LuPencil"


class LuPercent(rx.Component):
    library = "react-icons/lu"
    tag = "LuPercent"


class LuPersonStanding(rx.Component):
    library = "react-icons/lu"
    tag = "LuPersonStanding"


class LuPhoneCall(rx.Component):
    library = "react-icons/lu"
    tag = "LuPhoneCall"


class LuPhoneForwarded(rx.Component):
    library = "react-icons/lu"
    tag = "LuPhoneForwarded"


class LuPhoneIncoming(rx.Component):
    library = "react-icons/lu"
    tag = "LuPhoneIncoming"


class LuPhoneMissed(rx.Component):
    library = "react-icons/lu"
    tag = "LuPhoneMissed"


class LuPhoneOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuPhoneOff"


class LuPhoneOutgoing(rx.Component):
    library = "react-icons/lu"
    tag = "LuPhoneOutgoing"


class LuPhone(rx.Component):
    library = "react-icons/lu"
    tag = "LuPhone"


class LuPictureInPicture2(rx.Component):
    library = "react-icons/lu"
    tag = "LuPictureInPicture2"


class LuPictureInPicture(rx.Component):
    library = "react-icons/lu"
    tag = "LuPictureInPicture"


class LuPieChart(rx.Component):
    library = "react-icons/lu"
    tag = "LuPieChart"


class LuPiggyBank(rx.Component):
    library = "react-icons/lu"
    tag = "LuPiggyBank"


class LuPilcrow(rx.Component):
    library = "react-icons/lu"
    tag = "LuPilcrow"


class LuPill(rx.Component):
    library = "react-icons/lu"
    tag = "LuPill"


class LuPinOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuPinOff"


class LuPin(rx.Component):
    library = "react-icons/lu"
    tag = "LuPin"


class LuPipette(rx.Component):
    library = "react-icons/lu"
    tag = "LuPipette"


class LuPizza(rx.Component):
    library = "react-icons/lu"
    tag = "LuPizza"


class LuPlaneLanding(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlaneLanding"


class LuPlaneTakeoff(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlaneTakeoff"


class LuPlane(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlane"


class LuPlayCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlayCircle"


class LuPlay(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlay"


class LuPlug2(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlug2"


class LuPlugZap(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlugZap"


class LuPlug(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlug"


class LuPlusCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlusCircle"


class LuPlusSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlusSquare"


class LuPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuPlus"


class LuPocket(rx.Component):
    library = "react-icons/lu"
    tag = "LuPocket"


class LuPodcast(rx.Component):
    library = "react-icons/lu"
    tag = "LuPodcast"


class LuPointer(rx.Component):
    library = "react-icons/lu"
    tag = "LuPointer"


class LuPoundSterling(rx.Component):
    library = "react-icons/lu"
    tag = "LuPoundSterling"


class LuPowerOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuPowerOff"


class LuPower(rx.Component):
    library = "react-icons/lu"
    tag = "LuPower"


class LuPrinter(rx.Component):
    library = "react-icons/lu"
    tag = "LuPrinter"


class LuPuzzle(rx.Component):
    library = "react-icons/lu"
    tag = "LuPuzzle"


class LuQrCode(rx.Component):
    library = "react-icons/lu"
    tag = "LuQrCode"


class LuQuote(rx.Component):
    library = "react-icons/lu"
    tag = "LuQuote"


class LuRadiation(rx.Component):
    library = "react-icons/lu"
    tag = "LuRadiation"


class LuRadioReceiver(rx.Component):
    library = "react-icons/lu"
    tag = "LuRadioReceiver"


class LuRadioTower(rx.Component):
    library = "react-icons/lu"
    tag = "LuRadioTower"


class LuRadio(rx.Component):
    library = "react-icons/lu"
    tag = "LuRadio"


class LuRat(rx.Component):
    library = "react-icons/lu"
    tag = "LuRat"


class LuReceipt(rx.Component):
    library = "react-icons/lu"
    tag = "LuReceipt"


class LuRectangleHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuRectangleHorizontal"


class LuRectangleVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuRectangleVertical"


class LuRecycle(rx.Component):
    library = "react-icons/lu"
    tag = "LuRecycle"


class LuRedo2(rx.Component):
    library = "react-icons/lu"
    tag = "LuRedo2"


class LuRedo(rx.Component):
    library = "react-icons/lu"
    tag = "LuRedo"


class LuRefreshCcw(rx.Component):
    library = "react-icons/lu"
    tag = "LuRefreshCcw"


class LuRefreshCw(rx.Component):
    library = "react-icons/lu"
    tag = "LuRefreshCw"


class LuRefrigerator(rx.Component):
    library = "react-icons/lu"
    tag = "LuRefrigerator"


class LuRegex(rx.Component):
    library = "react-icons/lu"
    tag = "LuRegex"


class LuRemoveFormatting(rx.Component):
    library = "react-icons/lu"
    tag = "LuRemoveFormatting"


class LuRepeat1(rx.Component):
    library = "react-icons/lu"
    tag = "LuRepeat1"


class LuRepeat2(rx.Component):
    library = "react-icons/lu"
    tag = "LuRepeat2"


class LuRepeat(rx.Component):
    library = "react-icons/lu"
    tag = "LuRepeat"


class LuReplaceAll(rx.Component):
    library = "react-icons/lu"
    tag = "LuReplaceAll"


class LuReplace(rx.Component):
    library = "react-icons/lu"
    tag = "LuReplace"


class LuReplyAll(rx.Component):
    library = "react-icons/lu"
    tag = "LuReplyAll"


class LuReply(rx.Component):
    library = "react-icons/lu"
    tag = "LuReply"


class LuRewind(rx.Component):
    library = "react-icons/lu"
    tag = "LuRewind"


class LuRocket(rx.Component):
    library = "react-icons/lu"
    tag = "LuRocket"


class LuRockingChair(rx.Component):
    library = "react-icons/lu"
    tag = "LuRockingChair"


class LuRotate3D(rx.Component):
    library = "react-icons/lu"
    tag = "LuRotate3D"


class LuRotateCcw(rx.Component):
    library = "react-icons/lu"
    tag = "LuRotateCcw"


class LuRotateCw(rx.Component):
    library = "react-icons/lu"
    tag = "LuRotateCw"


class LuRouter(rx.Component):
    library = "react-icons/lu"
    tag = "LuRouter"


class LuRows(rx.Component):
    library = "react-icons/lu"
    tag = "LuRows"


class LuRss(rx.Component):
    library = "react-icons/lu"
    tag = "LuRss"


class LuRuler(rx.Component):
    library = "react-icons/lu"
    tag = "LuRuler"


class LuRussianRuble(rx.Component):
    library = "react-icons/lu"
    tag = "LuRussianRuble"


class LuSailboat(rx.Component):
    library = "react-icons/lu"
    tag = "LuSailboat"


class LuSalad(rx.Component):
    library = "react-icons/lu"
    tag = "LuSalad"


class LuSandwich(rx.Component):
    library = "react-icons/lu"
    tag = "LuSandwich"


class LuSatelliteDish(rx.Component):
    library = "react-icons/lu"
    tag = "LuSatelliteDish"


class LuSatellite(rx.Component):
    library = "react-icons/lu"
    tag = "LuSatellite"


class LuSaveAll(rx.Component):
    library = "react-icons/lu"
    tag = "LuSaveAll"


class LuSave(rx.Component):
    library = "react-icons/lu"
    tag = "LuSave"


class LuScale3D(rx.Component):
    library = "react-icons/lu"
    tag = "LuScale3D"


class LuScale(rx.Component):
    library = "react-icons/lu"
    tag = "LuScale"


class LuScaling(rx.Component):
    library = "react-icons/lu"
    tag = "LuScaling"


class LuScanFace(rx.Component):
    library = "react-icons/lu"
    tag = "LuScanFace"


class LuScanLine(rx.Component):
    library = "react-icons/lu"
    tag = "LuScanLine"


class LuScan(rx.Component):
    library = "react-icons/lu"
    tag = "LuScan"


class LuSchool2(rx.Component):
    library = "react-icons/lu"
    tag = "LuSchool2"


class LuSchool(rx.Component):
    library = "react-icons/lu"
    tag = "LuSchool"


class LuScissors(rx.Component):
    library = "react-icons/lu"
    tag = "LuScissors"


class LuScreenShareOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuScreenShareOff"


class LuScreenShare(rx.Component):
    library = "react-icons/lu"
    tag = "LuScreenShare"


class LuScroll(rx.Component):
    library = "react-icons/lu"
    tag = "LuScroll"


class LuSearch(rx.Component):
    library = "react-icons/lu"
    tag = "LuSearch"


class LuSend(rx.Component):
    library = "react-icons/lu"
    tag = "LuSend"


class LuSeparatorHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuSeparatorHorizontal"


class LuSeparatorVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuSeparatorVertical"


class LuServerCog(rx.Component):
    library = "react-icons/lu"
    tag = "LuServerCog"


class LuServerCrash(rx.Component):
    library = "react-icons/lu"
    tag = "LuServerCrash"


class LuServerOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuServerOff"


class LuServer(rx.Component):
    library = "react-icons/lu"
    tag = "LuServer"


class LuSettings2(rx.Component):
    library = "react-icons/lu"
    tag = "LuSettings2"


class LuSettings(rx.Component):
    library = "react-icons/lu"
    tag = "LuSettings"


class LuShare2(rx.Component):
    library = "react-icons/lu"
    tag = "LuShare2"


class LuShare(rx.Component):
    library = "react-icons/lu"
    tag = "LuShare"


class LuSheet(rx.Component):
    library = "react-icons/lu"
    tag = "LuSheet"


class LuShieldAlert(rx.Component):
    library = "react-icons/lu"
    tag = "LuShieldAlert"


class LuShieldCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuShieldCheck"


class LuShieldClose(rx.Component):
    library = "react-icons/lu"
    tag = "LuShieldClose"


class LuShieldOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuShieldOff"


class LuShieldQuestion(rx.Component):
    library = "react-icons/lu"
    tag = "LuShieldQuestion"


class LuShield(rx.Component):
    library = "react-icons/lu"
    tag = "LuShield"


class LuShip(rx.Component):
    library = "react-icons/lu"
    tag = "LuShip"


class LuShirt(rx.Component):
    library = "react-icons/lu"
    tag = "LuShirt"


class LuShoppingBag(rx.Component):
    library = "react-icons/lu"
    tag = "LuShoppingBag"


class LuShoppingCart(rx.Component):
    library = "react-icons/lu"
    tag = "LuShoppingCart"


class LuShovel(rx.Component):
    library = "react-icons/lu"
    tag = "LuShovel"


class LuShowerHead(rx.Component):
    library = "react-icons/lu"
    tag = "LuShowerHead"


class LuShrink(rx.Component):
    library = "react-icons/lu"
    tag = "LuShrink"


class LuShrub(rx.Component):
    library = "react-icons/lu"
    tag = "LuShrub"


class LuShuffle(rx.Component):
    library = "react-icons/lu"
    tag = "LuShuffle"


class LuSigma(rx.Component):
    library = "react-icons/lu"
    tag = "LuSigma"


class LuSignalHigh(rx.Component):
    library = "react-icons/lu"
    tag = "LuSignalHigh"


class LuSignalLow(rx.Component):
    library = "react-icons/lu"
    tag = "LuSignalLow"


class LuSignalMedium(rx.Component):
    library = "react-icons/lu"
    tag = "LuSignalMedium"


class LuSignalZero(rx.Component):
    library = "react-icons/lu"
    tag = "LuSignalZero"


class LuSignal(rx.Component):
    library = "react-icons/lu"
    tag = "LuSignal"


class LuSiren(rx.Component):
    library = "react-icons/lu"
    tag = "LuSiren"


class LuSkipBack(rx.Component):
    library = "react-icons/lu"
    tag = "LuSkipBack"


class LuSkipForward(rx.Component):
    library = "react-icons/lu"
    tag = "LuSkipForward"


class LuSkull(rx.Component):
    library = "react-icons/lu"
    tag = "LuSkull"


class LuSlack(rx.Component):
    library = "react-icons/lu"
    tag = "LuSlack"


class LuSlice(rx.Component):
    library = "react-icons/lu"
    tag = "LuSlice"


class LuSlidersHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuSlidersHorizontal"


class LuSliders(rx.Component):
    library = "react-icons/lu"
    tag = "LuSliders"


class LuSmartphoneCharging(rx.Component):
    library = "react-icons/lu"
    tag = "LuSmartphoneCharging"


class LuSmartphoneNfc(rx.Component):
    library = "react-icons/lu"
    tag = "LuSmartphoneNfc"


class LuSmartphone(rx.Component):
    library = "react-icons/lu"
    tag = "LuSmartphone"


class LuSmilePlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuSmilePlus"


class LuSmile(rx.Component):
    library = "react-icons/lu"
    tag = "LuSmile"


class LuSnowflake(rx.Component):
    library = "react-icons/lu"
    tag = "LuSnowflake"


class LuSofa(rx.Component):
    library = "react-icons/lu"
    tag = "LuSofa"


class LuSoup(rx.Component):
    library = "react-icons/lu"
    tag = "LuSoup"


class LuSpace(rx.Component):
    library = "react-icons/lu"
    tag = "LuSpace"


class LuSpeaker(rx.Component):
    library = "react-icons/lu"
    tag = "LuSpeaker"


class LuSpline(rx.Component):
    library = "react-icons/lu"
    tag = "LuSpline"


class LuSplitSquareHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuSplitSquareHorizontal"


class LuSplitSquareVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuSplitSquareVertical"


class LuSplit(rx.Component):
    library = "react-icons/lu"
    tag = "LuSplit"


class LuSprout(rx.Component):
    library = "react-icons/lu"
    tag = "LuSprout"


class LuSquareDot(rx.Component):
    library = "react-icons/lu"
    tag = "LuSquareDot"


class LuSquareEqual(rx.Component):
    library = "react-icons/lu"
    tag = "LuSquareEqual"


class LuSquareSlash(rx.Component):
    library = "react-icons/lu"
    tag = "LuSquareSlash"


class LuSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuSquare"


class LuStamp(rx.Component):
    library = "react-icons/lu"
    tag = "LuStamp"


class LuStarHalf(rx.Component):
    library = "react-icons/lu"
    tag = "LuStarHalf"


class LuStarOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuStarOff"


class LuStar(rx.Component):
    library = "react-icons/lu"
    tag = "LuStar"


class LuStars(rx.Component):
    library = "react-icons/lu"
    tag = "LuStars"


class LuStepBack(rx.Component):
    library = "react-icons/lu"
    tag = "LuStepBack"


class LuStepForward(rx.Component):
    library = "react-icons/lu"
    tag = "LuStepForward"


class LuStethoscope(rx.Component):
    library = "react-icons/lu"
    tag = "LuStethoscope"


class LuSticker(rx.Component):
    library = "react-icons/lu"
    tag = "LuSticker"


class LuStickyNote(rx.Component):
    library = "react-icons/lu"
    tag = "LuStickyNote"


class LuStopCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuStopCircle"


class LuStore(rx.Component):
    library = "react-icons/lu"
    tag = "LuStore"


class LuStretchHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuStretchHorizontal"


class LuStretchVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuStretchVertical"


class LuStrikethrough(rx.Component):
    library = "react-icons/lu"
    tag = "LuStrikethrough"


class LuSubscript(rx.Component):
    library = "react-icons/lu"
    tag = "LuSubscript"


class LuSubtitles(rx.Component):
    library = "react-icons/lu"
    tag = "LuSubtitles"


class LuSunDim(rx.Component):
    library = "react-icons/lu"
    tag = "LuSunDim"


class LuSunMedium(rx.Component):
    library = "react-icons/lu"
    tag = "LuSunMedium"


class LuSunMoon(rx.Component):
    library = "react-icons/lu"
    tag = "LuSunMoon"


class LuSunSnow(rx.Component):
    library = "react-icons/lu"
    tag = "LuSunSnow"


class LuSun(rx.Component):
    library = "react-icons/lu"
    tag = "LuSun"


class LuSunrise(rx.Component):
    library = "react-icons/lu"
    tag = "LuSunrise"


class LuSunset(rx.Component):
    library = "react-icons/lu"
    tag = "LuSunset"


class LuSuperscript(rx.Component):
    library = "react-icons/lu"
    tag = "LuSuperscript"


class LuSwissFranc(rx.Component):
    library = "react-icons/lu"
    tag = "LuSwissFranc"


class LuSwitchCamera(rx.Component):
    library = "react-icons/lu"
    tag = "LuSwitchCamera"


class LuSword(rx.Component):
    library = "react-icons/lu"
    tag = "LuSword"


class LuSwords(rx.Component):
    library = "react-icons/lu"
    tag = "LuSwords"


class LuSyringe(rx.Component):
    library = "react-icons/lu"
    tag = "LuSyringe"


class LuTable2(rx.Component):
    library = "react-icons/lu"
    tag = "LuTable2"


class LuTable(rx.Component):
    library = "react-icons/lu"
    tag = "LuTable"


class LuTablet(rx.Component):
    library = "react-icons/lu"
    tag = "LuTablet"


class LuTablets(rx.Component):
    library = "react-icons/lu"
    tag = "LuTablets"


class LuTag(rx.Component):
    library = "react-icons/lu"
    tag = "LuTag"


class LuTags(rx.Component):
    library = "react-icons/lu"
    tag = "LuTags"


class LuTarget(rx.Component):
    library = "react-icons/lu"
    tag = "LuTarget"


class LuTent(rx.Component):
    library = "react-icons/lu"
    tag = "LuTent"


class LuTerminalSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuTerminalSquare"


class LuTerminal(rx.Component):
    library = "react-icons/lu"
    tag = "LuTerminal"


class LuTestTube2(rx.Component):
    library = "react-icons/lu"
    tag = "LuTestTube2"


class LuTestTube(rx.Component):
    library = "react-icons/lu"
    tag = "LuTestTube"


class LuTestTubes(rx.Component):
    library = "react-icons/lu"
    tag = "LuTestTubes"


class LuTextCursorInput(rx.Component):
    library = "react-icons/lu"
    tag = "LuTextCursorInput"


class LuTextCursor(rx.Component):
    library = "react-icons/lu"
    tag = "LuTextCursor"


class LuTextSelect(rx.Component):
    library = "react-icons/lu"
    tag = "LuTextSelect"


class LuText(rx.Component):
    library = "react-icons/lu"
    tag = "LuText"


class LuThermometerSnowflake(rx.Component):
    library = "react-icons/lu"
    tag = "LuThermometerSnowflake"


class LuThermometerSun(rx.Component):
    library = "react-icons/lu"
    tag = "LuThermometerSun"


class LuThermometer(rx.Component):
    library = "react-icons/lu"
    tag = "LuThermometer"


class LuThumbsDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuThumbsDown"


class LuThumbsUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuThumbsUp"


class LuTicket(rx.Component):
    library = "react-icons/lu"
    tag = "LuTicket"


class LuTimerOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuTimerOff"


class LuTimerReset(rx.Component):
    library = "react-icons/lu"
    tag = "LuTimerReset"


class LuTimer(rx.Component):
    library = "react-icons/lu"
    tag = "LuTimer"


class LuToggleLeft(rx.Component):
    library = "react-icons/lu"
    tag = "LuToggleLeft"


class LuToggleRight(rx.Component):
    library = "react-icons/lu"
    tag = "LuToggleRight"


class LuTornado(rx.Component):
    library = "react-icons/lu"
    tag = "LuTornado"


class LuTouchpadOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuTouchpadOff"


class LuTouchpad(rx.Component):
    library = "react-icons/lu"
    tag = "LuTouchpad"


class LuTowerControl(rx.Component):
    library = "react-icons/lu"
    tag = "LuTowerControl"


class LuToyBrick(rx.Component):
    library = "react-icons/lu"
    tag = "LuToyBrick"


class LuTrain(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrain"


class LuTrash2(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrash2"


class LuTrash(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrash"


class LuTreeDeciduous(rx.Component):
    library = "react-icons/lu"
    tag = "LuTreeDeciduous"


class LuTreePine(rx.Component):
    library = "react-icons/lu"
    tag = "LuTreePine"


class LuTrees(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrees"


class LuTrello(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrello"


class LuTrendingDown(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrendingDown"


class LuTrendingUp(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrendingUp"


class LuTriangle(rx.Component):
    library = "react-icons/lu"
    tag = "LuTriangle"


class LuTrophy(rx.Component):
    library = "react-icons/lu"
    tag = "LuTrophy"


class LuTruck(rx.Component):
    library = "react-icons/lu"
    tag = "LuTruck"


class LuTv2(rx.Component):
    library = "react-icons/lu"
    tag = "LuTv2"


class LuTv(rx.Component):
    library = "react-icons/lu"
    tag = "LuTv"


class LuTwitch(rx.Component):
    library = "react-icons/lu"
    tag = "LuTwitch"


class LuTwitter(rx.Component):
    library = "react-icons/lu"
    tag = "LuTwitter"


class LuType(rx.Component):
    library = "react-icons/lu"
    tag = "LuType"


class LuUmbrella(rx.Component):
    library = "react-icons/lu"
    tag = "LuUmbrella"


class LuUnderline(rx.Component):
    library = "react-icons/lu"
    tag = "LuUnderline"


class LuUndo2(rx.Component):
    library = "react-icons/lu"
    tag = "LuUndo2"


class LuUndo(rx.Component):
    library = "react-icons/lu"
    tag = "LuUndo"


class LuUnfoldHorizontal(rx.Component):
    library = "react-icons/lu"
    tag = "LuUnfoldHorizontal"


class LuUnfoldVertical(rx.Component):
    library = "react-icons/lu"
    tag = "LuUnfoldVertical"


class LuUnlink2(rx.Component):
    library = "react-icons/lu"
    tag = "LuUnlink2"


class LuUnlink(rx.Component):
    library = "react-icons/lu"
    tag = "LuUnlink"


class LuUnlock(rx.Component):
    library = "react-icons/lu"
    tag = "LuUnlock"


class LuUploadCloud(rx.Component):
    library = "react-icons/lu"
    tag = "LuUploadCloud"


class LuUpload(rx.Component):
    library = "react-icons/lu"
    tag = "LuUpload"


class LuUsb(rx.Component):
    library = "react-icons/lu"
    tag = "LuUsb"


class LuUserCheck(rx.Component):
    library = "react-icons/lu"
    tag = "LuUserCheck"


class LuUserCog(rx.Component):
    library = "react-icons/lu"
    tag = "LuUserCog"


class LuUserMinus(rx.Component):
    library = "react-icons/lu"
    tag = "LuUserMinus"


class LuUserPlus(rx.Component):
    library = "react-icons/lu"
    tag = "LuUserPlus"


class LuUserX(rx.Component):
    library = "react-icons/lu"
    tag = "LuUserX"


class LuUser(rx.Component):
    library = "react-icons/lu"
    tag = "LuUser"


class LuUsers(rx.Component):
    library = "react-icons/lu"
    tag = "LuUsers"


class LuUtensilsCrossed(rx.Component):
    library = "react-icons/lu"
    tag = "LuUtensilsCrossed"


class LuUtensils(rx.Component):
    library = "react-icons/lu"
    tag = "LuUtensils"


class LuUtilityPole(rx.Component):
    library = "react-icons/lu"
    tag = "LuUtilityPole"


class LuVegan(rx.Component):
    library = "react-icons/lu"
    tag = "LuVegan"


class LuVenetianMask(rx.Component):
    library = "react-icons/lu"
    tag = "LuVenetianMask"


class LuVerified(rx.Component):
    library = "react-icons/lu"
    tag = "LuVerified"


class LuVibrateOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuVibrateOff"


class LuVibrate(rx.Component):
    library = "react-icons/lu"
    tag = "LuVibrate"


class LuVideoOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuVideoOff"


class LuVideo(rx.Component):
    library = "react-icons/lu"
    tag = "LuVideo"


class LuView(rx.Component):
    library = "react-icons/lu"
    tag = "LuView"


class LuVoicemail(rx.Component):
    library = "react-icons/lu"
    tag = "LuVoicemail"


class LuVolume1(rx.Component):
    library = "react-icons/lu"
    tag = "LuVolume1"


class LuVolume2(rx.Component):
    library = "react-icons/lu"
    tag = "LuVolume2"


class LuVolumeX(rx.Component):
    library = "react-icons/lu"
    tag = "LuVolumeX"


class LuVolume(rx.Component):
    library = "react-icons/lu"
    tag = "LuVolume"


class LuVote(rx.Component):
    library = "react-icons/lu"
    tag = "LuVote"


class LuWallet(rx.Component):
    library = "react-icons/lu"
    tag = "LuWallet"


class LuWallpaper(rx.Component):
    library = "react-icons/lu"
    tag = "LuWallpaper"


class LuWand2(rx.Component):
    library = "react-icons/lu"
    tag = "LuWand2"


class LuWand(rx.Component):
    library = "react-icons/lu"
    tag = "LuWand"


class LuWarehouse(rx.Component):
    library = "react-icons/lu"
    tag = "LuWarehouse"


class LuWatch(rx.Component):
    library = "react-icons/lu"
    tag = "LuWatch"


class LuWaves(rx.Component):
    library = "react-icons/lu"
    tag = "LuWaves"


class LuWebcam(rx.Component):
    library = "react-icons/lu"
    tag = "LuWebcam"


class LuWebhook(rx.Component):
    library = "react-icons/lu"
    tag = "LuWebhook"


class LuWheatOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuWheatOff"


class LuWheat(rx.Component):
    library = "react-icons/lu"
    tag = "LuWheat"


class LuWholeWord(rx.Component):
    library = "react-icons/lu"
    tag = "LuWholeWord"


class LuWifiOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuWifiOff"


class LuWifi(rx.Component):
    library = "react-icons/lu"
    tag = "LuWifi"


class LuWind(rx.Component):
    library = "react-icons/lu"
    tag = "LuWind"


class LuWineOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuWineOff"


class LuWine(rx.Component):
    library = "react-icons/lu"
    tag = "LuWine"


class LuWorkflow(rx.Component):
    library = "react-icons/lu"
    tag = "LuWorkflow"


class LuWrapText(rx.Component):
    library = "react-icons/lu"
    tag = "LuWrapText"


class LuWrench(rx.Component):
    library = "react-icons/lu"
    tag = "LuWrench"


class LuXCircle(rx.Component):
    library = "react-icons/lu"
    tag = "LuXCircle"


class LuXOctagon(rx.Component):
    library = "react-icons/lu"
    tag = "LuXOctagon"


class LuXSquare(rx.Component):
    library = "react-icons/lu"
    tag = "LuXSquare"


class LuX(rx.Component):
    library = "react-icons/lu"
    tag = "LuX"


class LuYoutube(rx.Component):
    library = "react-icons/lu"
    tag = "LuYoutube"


class LuZapOff(rx.Component):
    library = "react-icons/lu"
    tag = "LuZapOff"


class LuZap(rx.Component):
    library = "react-icons/lu"
    tag = "LuZap"


class LuZoomIn(rx.Component):
    library = "react-icons/lu"
    tag = "LuZoomIn"


class LuZoomOut(rx.Component):
    library = "react-icons/lu"
    tag = "LuZoomOut"


